@@ -1204,9 +1204,13 @@ static int startread_wav(sox_format_t * ft)
     /* ds64 size will have been applied in findChunk */
     qwDataLength = len;
     /* XXX - does MS_UNSPEC apply to RF64 files? */
-    if (qwDataLength == MS_UNSPEC) {
+    if (qwDataLength == 0x7FFFFFFF ||  /* LAME */
+        qwDataLength == 0xFFFFFFFF ||  /* FFMPEG and madplay */
+        qwDataLength == MS_UNSPEC) {   /* SoX only, apparently */
       wav->ignoreSize = 1;
-      lsx_debug("data length is unspecified; ignoring length");
+      /* This is to be expected when reading from a pipe */
+      if (ft->seekable)
+        lsx_warn("data length is unspecified; taking it from the file length");
     }
 
 
